*******************************
The sherpa.models.regrid module
*******************************

.. currentmodule:: sherpa.models.regrid

.. automodule:: sherpa.models.regrid

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      Axis
      IntegratedAxis
      PointAxis
      EvaluationSpace1D
      EvaluationSpace2D
      ModelDomainRegridder1D
      ModelDomainRegridder2D

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      rebin_2d
      rebin_int
      rebin_no_int

Class Inheritance Diagram
=========================

.. inheritance-diagram:: Axis IntegratedAxis PointAxis EvaluationSpace1D EvaluationSpace2D ModelDomainRegridder1D ModelDomainRegridder2D
   :parts: 1
